#
# spec file for package kexec-tools
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           kexec-tools
%ifarch ppc
BuildRequires:  gcc-64bit
BuildRequires:  glibc-devel-64bit
%endif
Requires:       perl-Bootloader
PreReq:         %fillup_prereq
Summary:        Tools for fast kernel loading
License:        GPL-2.0+
Group:          System/Kernel
Version:        2.0.12
Release:        4.2
Source:         ftp://kernel.org/pub/linux/utils/kernel/kexec/%{name}-%{version}.tar.xz
Source1:        kexec-bootloader
Source2:        kexec-bootloader.8.txt
Source3:        kexec-load.service
Source4:        %{name}-rpmlintrc
# common SLE/openSUSE patches
Patch1:         %{name}-xen-static.patch
Patch2:         %{name}-xen-balloon-up.patch
Patch3:         %{name}-disable-test.patch
Patch4:         %{name}-enable-aarch64.patch
Patch5:         %{name}-enable-aarch64-fixup.patch
Patch6:         %{name}-vmcoreinfo-in-xen.patch
Patch7:         %{name}-ppc64-reduce-elf-loads.patch
# SLE ONLY patches
Patch100:       %{name}-set-mmconf-reserved.patch
Patch101:       %{name}-xen-inhibit-file-based-syscall.patch
Url:            ftp://kernel.org/pub/linux/utils/kernel/kexec/%{name}-%{version}.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
#!BuildIgnore:  fop
BuildRequires:  asciidoc
BuildRequires:  automake
BuildRequires:  libxslt
BuildRequires:  zlib-devel
%ifarch         x86_64
BuildRequires:  pkg-config
BuildRequires:  xen-devel
%endif
ExclusiveArch:  ppc64le aarch64 %ix86 x86_64 ia64 ppc ppc64 s390 s390x %arm sh mips mipsel

%description
Kexec is a user space utility for loading another kernel and asking the
currently running kernel to do something with it. A currently running
kernel may be asked to start the loaded kernel on reboot, or to start
the loaded kernel after it panics.

%prep
%setup -q -n kexec-tools-%{version}
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
# temp disabled
#%patch100 -p1
%patch101 -p1

%build
# disable as-needed
export SUSE_ASNEEDED=0
%{?suse_update_config -f}
%ifarch ia64 ppc64le
RPM_OPT_FLAGS=$(echo $RPM_OPT_FLAGS | sed -e 's/-fstack-protector//')
%endif
autoreconf -f
CFLAGS=$RPM_OPT_FLAGS BUILD_CFLAGS=$RPM_OPT_FLAGS \
%ifarch ppc
%configure --host=powerpc64-suse-linux --build=powerpc64-suse-linux 
%else
%configure
%endif
make
a2x -D . -d manpage -f manpage %{S:2}

%install
%makeinstall
install -c -m 0644 kexec-bootloader.8 $RPM_BUILD_ROOT%{_mandir}/man8
rm -f $RPM_BUILD_ROOT%{_mandir}/man8/kdump.8
mkdir -p $RPM_BUILD_ROOT%{_sbindir}
install -m 0755 %{S:1} $RPM_BUILD_ROOT%{_sbindir}
mkdir -p $RPM_BUILD_ROOT%{_unitdir}
install -m644 %{S:3} $RPM_BUILD_ROOT%{_unitdir}
#UsrMerge
mkdir -p $RPM_BUILD_ROOT/sbin
ln -s %{_sbindir}/kdump $RPM_BUILD_ROOT/sbin
ln -s %{_sbindir}/kexec $RPM_BUILD_ROOT/sbin
#EndUsrMerge

%clean
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

%post
%service_add_post kexec-load.service

%postun
%service_del_postun kexec-load.service

%pre
%service_add_pre kexec-load.service

%preun
%service_del_preun kexec-load.service

%files
%defattr(-, root, root)
%doc AUTHORS COPYING News TODO doc
%doc %{_mandir}/man*/*
#UsrMerge
/sbin/kdump
/sbin/kexec
#EndUsrMerge
%{_sbindir}/kdump
%{_sbindir}/kexec
%{_sbindir}/kexec-bootloader
%{_sbindir}/vmcore-dmesg
%{_unitdir}/kexec-load.service

%changelog
* Wed May 10 2017 carnold@suse.com
- kexec-tools-xen-static.patch: xen breaks kexec-tools build
  (bsc#1037779)
  See also matching fix in xen-devel package
* Thu Jun  2 2016 tonyj@suse.com
- Update to version 2.0.12 (FATE#320915, bsc#980545)
  Changelog: http://git.kernel.org/cgit/utils/kernel/kexec/kexec-tools.git/log/?id=refs/tags/v2.0.5..v2.0.12
  Drop following patches (upstream):
    kexec-tools-Provide-an-option-to-use-new-kexec-system-call.patch
    kexec-tools-fs2dt-fix-endianess-issue-with-initrd-base-and-size.patch
    kexec-tools-i386-bzimage_efi.patch
    kexec-tools-kdump-fix-elf-header-endianess.patch
    kexec-tools-load-crash-kernel-high.patch
    kexec-tools-ppc64-purgatory-device-tree-values-should-be-read-stored-in-big-endian.patch
    kexec-tools-zero-efi-info.patch
  Refresh following patches for SLE12 (context):
    kexec-tools-vmcoreinfo-in-xen.patch
    kexec-tools-xen-balloon-up.patch
    kexec-tools-xen-e820-redefinition.patch
    kexec-tools-xen-static.patch
  Temporarily disable following SGI patch pending further analysis
    kexec-tools-set-mmconf-reserved.patch
* Mon May 30 2016 ptesarik@suse.com
- kexec-tools-ppc64-reduce-elf-loads.patch: ppc64: Reduce number of
  ELF LOAD segments (bsc#981339).
* Tue May  3 2016 ohering@suse.de
- Adjust linking to libxenctrl to xen-4.7 API (fate#319989)
* Mon Oct 26 2015 ptesarik@suse.cz
- kexec-tools-vmcoreinfo-in-xen.patch: Store XEN_VMCOREINFO in
  panic kernel ELF notes.
  (bsc#951740)
* Tue Oct 13 2015 jlee@suse.com
- kexec-tools-xen-inhibit-file-based-syscall.patch: To inhibit file
  based syscall on XEN, using old syscall to load crash kernel.
  (bsc#947172)
* Tue Oct  6 2015 ptesarik@suse.com
- kexec-tools-load-crash-kernel-high.patch: Load crash kernel high
  on x86 (bsc#946365).
* Mon May  4 2015 jlee@suse.com
- Add 'kexec-tools/kexec-tools-Provide-an-option-to-use-new-kexec-system-call.patch'
  to support kdump on secure boot. (fate#315018, bnc#884453)
* Tue Aug 19 2014 tonyj@suse.com
- custom autoconf action was no longer setting HAVE_LIBXENCTRL (bnc#886873)
* Fri Aug 15 2014 tonyj@suse.com
- Do not package kdump.8 as it is only a placeholder, full man page is provided
  by kdump package (bnc#892090)
* Sat Jul 26 2014 tonyj@suse.com
- Fix ELF header endianess for ppc64le kdump (bnc#888150)
  New patch: kexec-tools-kdump-fix-elf-header-endianess.patch
* Sun Jul 20 2014 p.drouand@gmail.com
- Remove insserv dependency; the package doesn't provide any sysvinit
  script
* Thu May  1 2014 tonyj@suse.com
- Device tree values should be big endian for ppc64le (bnc#875485)
  New patch: kexec-tools-ppc64-purgatory-device-tree-values-should-be-read-stored-in-big-endian.patch
* Fri Apr 11 2014 tonyj@suse.com
- Expose flattened device trees (ppc64le) to new kexec'd kernel in Big Endian
  format (bnc#873169)
    New patch: kexec-tools-fs2dt-fix-endianess-issue-with-initrd-base-and-size.patch
- Update patch headers to reflect upstream commit id's:
    Change patch: kexec-tools-ppc64-purgatory-disabling-gcc-stack-protection.patch
    Change patch: kexec-tools-zero-efi-info.patch
* Tue Mar 18 2014 tonyj@suse.com
- Reserve mmconf areas for kdump kernel via memmap=X$Y in cmdline
  (bnc#819777 [original: bnc#804800]: fix still needed for SGI UV systems).
  New patch: kexec-tools-set-mmconf-reserved.patch
- Disable stack protector for ppc64le (bnc#869161)
  New patch: kexec-tools-ppc64-purgatory-disabling-gcc-stack-protection.patch
- Disable erroneous (efi memory descriptor version) message (bnc#867785c5)
  New patch: kexec-tools-zero-efi-info.patch
* Wed Feb  5 2014 tonyj@suse.com
- Drop obsolete /etc/init.d/kexec (bnc# 862143).
- Handle btrfs root subvolume (bnc# 862143c35)
- Create kexec-load.service (bnc# 862143)
- Update kexec-bootloader manpage (document reboot using kexec)
- Remove old 11.1 conditionals
- Update kexec-tools-i386-bzimage_efi.patch and
  kexec-tools-xen-e820-redefinition.patch with upstream commit ids
* Wed Feb  5 2014 tonyj@suse.com
- Update to version 2.0.5
  Drop patch 'device-tree-buffer-overflows.patch' (upstream)
  Drop patch '0001-kexec-fs2dt-fix-endianess-conversion.patch' (upstream)
- Rename aarch64 patch to 'kexec-tools-enable-aarch64.patch' and rebase to
  version from Linaro git.
- Add 'kexec-tools-enable-aarch64-fixup.patch' to solve arm libfdt breakage
  with Linaro patch.
- Enable ppc64le
- Refresh patches for context.
- Add following patches (pending upstream):
  'kexec-tools-i386-bzimage_efi.patch' to fix i386 breakage.
  'kexec-tools-xen-e820-redefinition.patch' to fix xen/820 breakage.
* Tue Feb  4 2014 dmueller@suse.com
- add 0001-kexec-fs2dt-fix-endianess-conversion.patch:
  * fix ppc64 and arm
- refresh device-tree-buffer-overflows.patch with the version
  that went upstream
* Mon Feb  3 2014 dmueller@suse.com
- enable build for arm / aarch64
- add kexec-aarch64.patch
- add device-tree-buffer-overflows.patch
* Thu Jan  9 2014 tonyj@suse.com
- Update to version 2.0.4
- Drop patches (mainline):
  kexec-tools-fix-makefile-binaries.patch (aaedd532)
  kexec-tools-fix-strncat.patch (d5efc524)
  kexec-tools-no-vga-output.patch (f1facd4b)
* Sun Jan  5 2014 coolo@suse.com
- xen 4.4 is exclusive to 64bit archs, so don't require it
* Fri Dec  6 2013 ptesarik@suse.cz
- Remove double-packaging of /etc/init.d/kexec-tools, fixing build
  errors on some targets, e.g. SLE-11.
* Thu Apr 11 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Thu Oct 11 2012 tonyj@suse.com
- Update to kexec 2.0.3.  Drop unneeded patches.
* Thu Jun 14 2012 ohering@suse.de
- Fix xen cpuid() inline asm to not clobber stack's red zone
  See xen-unstable changeset 24344:72f4e4cb7440
* Thu Jun 14 2012 ohering@suse.de
- Balloon up in a Xen PVonHVM guest before kexec (bnc#694863)
- Update xen_present check for xenfs in pv_ops kernel (bnc#694863)
- Change xen_present hv check (bnc#658413)
* Fri Apr 20 2012 rschweikert@suse.com
- place binaries into /usr tree (UsrMerge project)
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Sun Jul 10 2011 meissner@suse.de
- fixed strncat sizse argument on ppc
* Tue May 17 2011 jslaby@suse.de
- fix build with gcc that doesn't understand --no-undefined
* Sun Sep 12 2010 bernhard@bwalle.de
- Update to kexec-tools 2.0.2 (bug fix release). The complete
  changelog can be viewed at
  http://git.kernel.org/?p=utils/kernel/kexec/kexec-tools.git;a=shortlog;h=refs/tags/v2.0.2.
- Drop kexec-tools-increase-kernel-text-size.diff: Mainline.
* Tue Mar 16 2010 ro@suse.de
- disable autoreconf to fix build
- drop obsolete patch ARM_kexec-zImage-arm_page_to_unistd.diff
* Wed Feb 10 2010 jengelh@medozas.de
- Add ExclusiveArch to specfile according to source capabilities
* Sun Dec 20 2009 bernhard@bwalle.de
- Update to kexec-tools 2.0.1 (bug fix release).
- Drop following patches because they are upstream now (or the
  problem is fixed otherwise upstream):
  o kexec-tools-ia64-uncached-memory.diff
  o kexec-tools-ia64-PA.diff
  o kexec-tools-build-warnings.diff
  o kexec-tools-ppc64-build-warnings.diff
  o kexec-tools-ppc64-IBM-QS2x-blades.diff
  o kexec-tools-ia64-kdump-PT_LOAD-order.diff
  o kexec-tools-crash-memory-ranges-drconf.diff
  o kexec-tools-add-usable-drconf-memory-node-to-device-tree.diff
  o kexec-tools-get-details-dynamic-reconfiguration-memory-node.diff
  o kexec-tools-get-details-dynamic-reconfiguration-memory-node.diff
  o kexec-tools-device-tree-return.diff
  o kexec-tools-ppc-check-flags.diff
  o kexec-tools-spell.diff
  o kexec-tools-proc-iomem-xen.diff
  o kexec-tools-parse-iomem-single-warning.diff
  o kexec-tools-exclude-gart.diff
  o kexec-tools-ppc64-memory-ranges-dynamic.diff
  o kexec-tools-ppc64-dynamic-fix-1.diff
  o kexec-tools-ppc64-dynamic-fix-2.diff
  o kexec-tools-ppc64-dynamic-fix-3.diff
  o kexec-tools-ppc64-reinit.diff
* Mon Sep 21 2009 jansimon.moeller@opensuse.org
- fix build on arm. kexec-zImage-arm needed s#asm/page.h#unistd.h#
* Wed Aug 12 2009 tiwai@suse.de
- increase kernel text size to fix for 2.6.31 kernel (bnc#530240)
* Sun Jul 12 2009 coolo@novell.com
- disable as-needed to fix build
* Thu Feb  5 2009 bwalle@suse.de
- Re-initialize drconf variables for PPC64 (bnc #468571).
* Wed Feb  4 2009 tiwai@suse.de
- fix build failure due to missing xsltproc
* Fri Jan 16 2009 bwalle@suse.de
- The dynamic reallocation for PPC64 broke kdump completely.
  Fix the patch so that dynamic reallocation actually works
  without memory corruption (bnc #466782).
* Fri Jan 16 2009 bwalle@suse.de
- Add #!BuildIgnore on fop to speed up build (asciidoc don't
  require fop for manpage generation).
* Wed Jan  7 2009 bwalle@suse.de
- Allocate memory ranges dynamically on PPC64 (bnc #460752).
* Tue Dec  9 2008 bwalle@suse.de
- Exclude GART memory from regions that must be written to the
  dump file (bnc #457612).
* Wed Nov 26 2008 bwalle@suse.de
- Fix compile warning.
* Mon Nov 24 2008 bwalle@suse.de
- Read memory map from /proc/iomem instead of /sys/firmware/memmap
  when running under Xen.
- Build against libxenctl on i386 and x86-64 but link statically
  to avoid runtime dependencies that would exist even on non-Xen
  systems.
* Fri Nov 14 2008 bwalle@suse.de
- Fix spell error in help output (bnc#444714).
* Sat Nov  1 2008 bwalle@suse.de
- Don't print "setup_linux_vesafb" message on stderr.
* Mon Oct 27 2008 bwalle@suse.de
- Update patch that checks for reserved and assigned bit flags on
  the memory regions (bnc#438086).
* Sun Oct 26 2008 bwalle@suse.de
- Clear grubonce after using in kexec-bootloader (bnc#438194).
- Add rpmlint supression file.
- Correct debugging output: Number of section was one too small
  (last index != size of array).
* Fri Oct 24 2008 bwalle@suse.de
- Check for reserved and assigned bit flags on the memory regions
  (bnc#438086).
* Sat Oct 18 2008 bwalle@suse.de
- Honor grubonce also when the 1st (== 0th) entry was chosen.
* Mon Oct 13 2008 bwalle@suse.de
- Fix runlevels (Default-Start, Default-Stop) in kexec.init.
- Only load kexec kernel when kexec reboot is enabled when the
  target runlevel is 6 (reboot) to avoid slowdown of shutdown in
  that case.
* Thu Oct  9 2008 bwalle@suse.de
- PPC64: Use return value of count_dyn_reconf_memory_ranges().
* Thu Oct  9 2008 bwalle@suse.de
- Fix empty /proc/vmcore on PPC64 (bnc#431492).
  o kexec/kdump: read crash memory ranges from drconf memory.
  o kexec/kdump: add a new linux, usable-drconf-memory node to the
    device tree.
  o kexec/kdump: get details of ibm, dynamic-reconfiguration-memory
    node of device tree.
* Thu Oct  9 2008 bwalle@suse.de
- Add newline in error message of "kexec-bootloader".
- Add error handling when Bootloader::Tools::GetDefaultSection()
  fails.
* Wed Oct  8 2008 bwalle@suse.de
- IA64: Order of operations bug in PT_LOAD segment reader.
* Wed Oct  8 2008 bwalle@suse.de
- ia64: Do not include uncached memory to vmcore.
- ia64: Make PA() work for both physical identity-mapped virtual
  addresses.
- PPC64: Let kexec work on IBM QS2x blade servers
- Fix build warnings.
* Mon Oct  6 2008 bwalle@suse.de
- Implement -h (help) option (bnc#432386).
- Remove documentation of -o (options) option that never existed.
* Wed Aug 27 2008 bwalle@suse.de
- only install and build /etc/init.d/kexec with openSUSE 11.1 /
  SLES 11 and later
* Sat Aug 16 2008 bwalle@suse.de
- mark /etc/init.d/kexec as %%config
- remove (empty) %%preun
* Fri Aug 15 2008 bwalle@suse.de
- add /etc/init.d/kexec to be able to reboot with kexec(8)
  (FATE#302238)
* Sat Jul 19 2008 bwalle@suse.de
- update to kexec-tools 2.0.0 (final)
  o Allow BUILD_CFLAGS and TARGET_CFLAGS to be specified at
    configure time
* Mon Jul 14 2008 bwalle@suse.de
- update to kexec-tools 2.0.0-rc1
  o implement support for /sys/firmware/memmap interface
  o Allow 32 bit kexec binary to boot kdump kernel on ppc64
    architecture
  o kexec/crashdump.c: remove file descriptor leaks; make
    kdump_info argument to get_vmcoreinfo() const
  o Fix implicit declaration of inb/outb
  o EDD implementation
  o Specify the arch on kexec_unload
  o Update KEXEC_ARCH_* constants from Linux kernel headers
  o lots of code cleanup
  o Add --reuse-cmdline
  o documentation update (manpage, boot protocol)
  o ensure that extra rtas segment is a multiple of PAGE_SIZE
  o Allow building for ppc32 platforms
  o Die on early EOF in slurp_file, instead of infinite-looping
  o Fix copy-paste bug: entry16 does not start at entry16_debug
  o Fix undefined symbol errors on readw/writew: arch/io.h, not
    sys/io.h
  o extract vmcoreinfo from /proc/vmcore for Xen
  o Give installed files user-writable permission
  o Use separate CPPFLAGS and LDFLAGS for purgatory
- dropped kexec-tools-fix-arch-on-unload: merged upstream
- dropped kexec-tools-edd-fix: merged upstream
- dropped kexec-tools-refactor-architecture-detection: merged
  upstram
- dropped kexec-tools.gcc-bug.patch: merged upstream
- dropped kexec-tools.ppc32-64bit-purgatory.patch: merged upstream
- kexec-tools-edd-support: merged upstream
- kexec-tools-32bit-kexec-with-64bit-ppc64.patch: merged upstream
- removed README.SUSE: information not necessary any more
* Thu Jul  3 2008 bwalle@suse.de
- fix 32 bit kexec to boot on 64 bit ppc64 (bnc#405015)
* Mon May 26 2008 bwalle@suse.de
- fix EDD support when the BIOS-reported length is smaller than
  the sysfs raw_data size (bnc#388754)
* Mon May 26 2008 bwalle@suse.de
- fix kexec unload (rckdump stop) on ppc64 (bnc#394216)
* Tue May 13 2008 bwalle@suse.de
- implement EDD (bnc#383210)
* Mon Mar 24 2008 bwalle@suse.de
- update to kexec-tools-testing v20080324
  o tarball update (version), no functional changes between
    v20080318-rc and v20080324
* Tue Mar 18 2008 bwalle@suse.de
- update to kexec-tools-testing v20080318-rc
  o ia64 kern_vaddr_start was calculated incorrectly
  o ia64: make load_crashdump_segments 80col wide
  o fix i386 EFI boot using efifb
  o mipsel: mipsel port
  o fix kexec-tools on x86_64 (see bnc#368138)
  o fix valid_memory_range region merging
  o arm: invalid initialisation of iomem in get_memory_ranges()
  o arm: use proc_iomem()
  o no machine machine to proc_iomem()
* Fri Mar 14 2008 bwalle@suse.de
- update to kexec-tools-testing v20080227-git
  (current git snapshot, fixes x86_64, bnc#368138)
- kexec-tools-portability-issue deleted: mainline
* Wed Feb 27 2008 bwalle@suse.de
- update to kexec-tools-testing v20080227
  (only increased version number)
* Tue Feb 26 2008 bwalle@suse.de
- update to kexec-tools-testing v20080226-rc
  o build: include configure and include/config.h.in in dist
    tarball
- adjusted kexec-tools-portability-issue to build without warnings
  on 32 bit systems
* Thu Feb 21 2008 bwalle@suse.de
- update to kexec-tools-testing v20080221-rc
  o Only include needed files in distribution tarball
  o Clean up whitespace in include/x86/x86-linux.h
  o Kexec command line length
- removed kexec-longer-cmdline.diff: fixed mainline differently
* Wed Feb 20 2008 bwalle@suse.de
- update to kexec-tools-testing v20080219-rc
  o Fix the feature determining ELF32/ELF64 automatically
  o Enable building a 32 bit binary for ppc64 platforms.
  o Consolidate BOOTLOADER defines
  o Use config.h for defines
  o Add gamecube to config.h defines
  o removed partially duplicated system headers
  o Use general _SRCS and _OBJS, rather and _C_{SRCS, OBJS} and
    _S_{SRCS, OBJS}
  o build system fixes
  o Add documentation on creating include/config.h.in to INSTALL
  o Log unknown reloc name instead of its number
  o Use zlib if present
  o kexec buffer overflow on ppc platform
  o sh: Remove hardcoded PAGE_SIZE in NetBSD loader
  o Add ARM support to kexec
  o Remove some extraneous whitespace
  o kexec: Use target linker for purgatory
- removed kexec-tools-elf32-elf64-fix: mainline
- removed kexec-tools.ppc64-32bit-build.patch: mainline
- removed kexec-tools.fread-buffer-overflow.patch: mainline
* Wed Jan 30 2008 sassmann@suse.de
- fix fread buffer overflow on ppc
* Tue Jan 22 2008 ro@suse.de
- update ppc buildreq
* Fri Nov 30 2007 bwalle@suse.de
- fix a problem with automatic determination of ELF32/ELF64 on i386
* Tue Oct 30 2007 bwalle@suse.de
- update to kexec-tools-testing 20071030
  o vmcoreinfo's address and size
* Wed Oct 17 2007 bwalle@suse.de
- update to kexec-tools-testing v20071017-rc
  o Set alternate location for /proc/iomem on ia64 xen
  o debugging output improvements
  o Handle malloc() failure in xen_get_nr_phys_cpus()
  o Added generic --reuseinitrd option
  o ppc64: fix device-tree mem node
  o ppc64: fix misaligned cmdline
  o ppc64: cleanup get_devtree_details
  o ppc64: Add arch specific --reuseinitrd hooks
  o ppc64: use kernels slave loop for purgatory
  o ppc64: correct @ha relocation
- remove kexec-tools.check_reuse_initrd-close.patch (merged
  mainline)
* Thu Oct 11 2007 bwalle@suse.de
- remove kdump stuff from this package, that's now in the "kexec"
  package
* Wed Aug 29 2007 bwalle@suse.de
- add reset_devices kernel parameter as default
* Sat Aug 25 2007 olh@suse.de
- do not require kdump-helpers on s390
* Fri Jul 27 2007 bwalle@suse.de
- update documentation for deleting all dumps (#302257)
* Mon Jul 16 2007 olh@suse.de
- workaround gcc code analyzing bug
* Mon Jul 16 2007 olh@suse.de
- update to kexec-tools-testing b84b87747a16f0afbef6f6802bb794a94f4961d9
  build 32bit powerpc kexec binary for 64bit kernels
* Fri Jul  6 2007 tiwai@suse.de
- implement a simple status command for kdump init script
* Mon Jul  2 2007 bwalle@suse.de
- removed 'machvec=dig' workaround from the documentation since
  this has been fixed in the kernel (#271158)
* Fri Jun 22 2007 bwalle@suse.de
- disable -fstack-protector on IA64 since the kdump kernel doesn't
  boot with -fstack-protector enabled
* Thu Jun 21 2007 bwalle@suse.de
- kdump init script: fix handling of spaces in kernel type
* Wed Jun 13 2007 bwalle@suse.de
- remove KDUMP_KERNELVER="kdump" on x86_64 and i386 since there's
  no special "kdump" kernel any more in the default configuration
  (i.e. in the .spec file since it's different for the
  architectures)
* Wed Jun 13 2007 bwalle@suse.de
- removed libelf as BuildRequires
* Mon Jun 11 2007 bwalle@suse.de
- moved copying of dump file to an external package
  "kdump-helpers"
- moved kdump-helper which is needed to save dump in initrd
  also to kdump-helpers package
* Tue Apr 24 2007 olh@suse.de
- update to current kexec-tools-testing
  add PS3 patches
* Thu Apr 19 2007 bwalle@suse.de
- fixes in kdump-helper (update to 0.1.2):
  o retrieve the disk size before mmap()
  o return GENERAL_ERROR if the program cannot be opened
  o use symbolic constants for exit values instead of magic numbers
    now consistently
  o check for correct return value of mmap() instead of NULL
* Fri Apr 13 2007 bwalle@suse.de
- improved documentation of KDUMP_DUMPDEV (#264050)
* Mon Apr  2 2007 rguenther@suse.de
- add zlib-devel BuildRequires
* Tue Mar 20 2007 bwalle@suse.de
- fixed script to properly unload kdump on IA64 (where kdump
  kernel is the normal kernel) (#256179)
* Mon Mar 19 2007 bwalle@suse.de
- upgrade to latest snapshot
  o [IA64] Use EFI_LOADER_DATA for ELF core header (-> needed
    because kernel was updated to 2.6.21 on STABLE)
  o include latest fixes
* Wed Mar 14 2007 tiwai@suse.de
- add detailed description about dump triggering methods to
  README.SUSE (#250134)
* Wed Mar 14 2007 tiwai@suse.de
- improve the check of crash kernel in kdump init script (#252632)
* Fri Mar  9 2007 bwalle@suse.de
- added hint that VGA console doesn't work (#253173)
* Thu Feb 15 2007 bwalle@suse.de
- added setting to print the kdump command line to standard output
- small improvement for the outut message while dumping: last
  message always prints 100%% if it was sucessful
* Wed Feb 14 2007 bwalle@suse.de
- added KDUMP_VERBOSE option to print progress output while
  dumping and to add the kexec call to system log
- added maxcpus=1 as default for KDUMP_COMMANDLINE_APPEND on IA64
- added --noio as default for KEXEC_OPTIONS on IA64
* Tue Feb 13 2007 bwalle@suse.de
- align the both start and end address of the ELF core header
  to EFI_PAGE_SIZE (4096) to fix wrong EFI memory maps
  (#214865)
* Mon Feb 12 2007 bwalle@suse.de
- fixed copying, blocksize was wrong (#243058)
* Sat Feb 10 2007 schwab@suse.de
- Fix help string.
* Fri Feb  9 2007 bwalle@suse.de
- fixed overflow error that prints the size from being printed
  correctly if the size doesn't fit into an int (#243058)
- improved error handling to make sure that a similar problem as
  in #243058 will output a better error message
* Wed Feb  7 2007 bwalle@suse.de
- don't refuse to deinstall kexec-tools if kdump was not configured
  (#243081)
- fixed documentation error (/var/log/dump instead of
  /var/log/dumps in README.SUSE)
  (#239506)
* Mon Feb  5 2007 tiwai@suse.de
- updated to kexec-tools 2007.02.05:
  * including last fixes
  * fix for ppc64 dynamic memory range allocation (#242075)
* Fri Feb  2 2007 bwalle@suse.de
- fixes overflow on large IA64 systems (#241544)
- added KDUMP_COMMANDLINE_APPEND variable (#241607)
- increase the command line size (#236828)
* Mon Jan 29 2007 olh@suse.de
- do not unload kdump kernel during runlevel changes (#238733)
* Thu Jan 25 2007 bwalle@suse.de
- added documentation for initrd-based kdump saving
- fixed description of KDUMP_IMMEDIATE_REBOOT
* Wed Jan 24 2007 tiwai@suse.de
- fix invalid /proc/vmcore on ppc64 (#238078).
* Thu Jan 18 2007 bwalle@suse.de
- improved documentation as response to #226736
* Wed Jan 17 2007 bwalle@suse.de
- implemented Initrd based kdump saving
  (#301538)
* Wed Dec 20 2006 tiwai@suse.de
- take kexec-tools-testing snapshot-20061219.
  o ia64 support
  o relocatable kernel support
  o lots of cleanups/fixes
- fix manpage and help about -u option (#208710)
- ia64 kdump support (#214865, FATE#301433, FATE#301434)
  o add boot argument "CRASH=1" to indicate the crash environment
    (for kexec'ing with the same kernel)
  o fix kdump init script for ia64, which has only vmlinuz and
    uses the same kernel for kdump
- reduce boot options for kdump kernel (#223500)
* Thu Jul 13 2006 tiwai@suse.de
- fixed the calculation of required disk space in kdump
  init script (#192172)
- fix the wrong usage of crash program in README.SUSE
* Thu Jun 22 2006 tiwai@suse.de
- fix kexec to reserve ACPI NVS area (#179093)
- add more description about chkconfig and kdump service
  (#183017)
* Fri Jun 16 2006 tiwai@suse.de
- add irqpoll boot option for i386 and x86_64 for more robust
  kdump (#183017)
* Thu Jun  1 2006 tiwai@suse.de
- update README.SUSE for more precise description about crash
  and debug kernel.
* Tue May 30 2006 tiwai@suse.de
- ppc64 kdump ELF header fix for power 4 box (#175128).
* Mon May 22 2006 tiwai@suse.de
- added the missing man page for kexec (#175084).
- add sleep after reboot in kdump init script for avoiding
  confliction with script single (#171332)
* Fri May 19 2006 olh@suse.de
- unconditionally add sysrq=1 for kdump boots, nothing to lose
* Fri May 19 2006 olh@suse.de
- remove crashkernel= cmdline also if only the size is given
  handle m as well as M because memparse() handles both
* Tue May  2 2006 tiwai@suse.de
- update/improve README.SUSE
- fix the default value in sysconfig.kdump
- add elevator=deadline to the boot parameter of kdump kernel
  to save memory footprint (#170591)
* Fri Apr 28 2006 olh@suse.de
- use df -P to print all data for a mount point in a single line
  long device node names will cause 2 lines in df output
* Wed Apr 26 2006 olh@suse.de
- linux,platform properties were removed from kernel 2.6.17
  assume non-LPAR if some properties do no exist in the device-tree
  (164993 - LTC23056)
* Wed Apr 26 2006 olh@suse.de
- set /proc/sys/kernel/panic_on_oops to actually trigger a dump
* Wed Mar  8 2006 olh@suse.de
- add --args-linux only on intel
  copy vmcore with --sparse, maybe it saves a few bytes.
* Wed Feb 22 2006 tiwai@suse.de
- updated to kdump7 patch.
* Wed Feb 15 2006 tiwai@suse.de
- fixed gdb-kdump script (#151001)
* Mon Feb 13 2006 tiwai@suse.de
- fix for ppc64 (#149576)
* Sun Feb 12 2006 tiwai@suse.de
- added the system check before dumping
- added README.SUSE
- added gdb-kdump helper script
* Thu Feb  9 2006 tiwai@suse.de
- fixed Default-Start in kdump init script.
- fixed RequiredStart in sysconfig/kdump.
* Wed Feb  8 2006 tiwai@suse.de
- changed the default values of KDUMP_IMMEDIATE_REBOOT and
  KDUMP_RUNLEVEL (#149140).
* Tue Feb  7 2006 tiwai@suse.de
- added missing preun and postun sections.
* Mon Feb  6 2006 tiwai@suse.de
- fixed the messages from kdump to use suse rc macros
- added $KDUMP_RUNLEVEL to /etc/sysconfig/kdump for specifying
  the runlevel to boot kdump kernel.
- added /sbin/rckdump
- fixed a typo in kdump init script
* Fri Feb  3 2006 tiwai@suse.de
- sync with mainstream dump6 patch:
  most of ppc64 patches were merged there.
  new fixes included: vmcore copy fix for x86_64 and ext_mem_k
  calculation fix for i386
- added KEXEC_TRANSFER sysconfig variable for user-defined
  dump action.
* Fri Jan 27 2006 tiwai@suse.de
- added kdump init script and sysconfig.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 olh@suse.de
- update ppc64 kdump support
* Thu Jan  5 2006 tiwai@suse.de
- more fix for ppc64 kdump
- fix malloc size
* Thu Dec 15 2005 tiwai@suse.de
- use the latest kdump patch.
* Mon Dec 12 2005 tiwai@suse.de
- initial version: 1.101
